@@ -1,13 +1,7 @@
 import asyncio
-import sys
 
 import pytest
 
-collect_ignore = []
-if sys.version_info[:2] < (3, 6):
-    collect_ignore.append("async_fixtures/test_async_gen_fixtures_36.py")
-    collect_ignore.append("async_fixtures/test_nested_36.py")
-
 
 @pytest.fixture
 def dependent_fixture(event_loop):
@@ -26,3 +20,11 @@ def dependent_fixture(event_loop):
     event_loop.run_until_complete(just_a_sleep())
 
     assert counter == 2
+
+
+@pytest.fixture(scope="session", name="factory_involving_factories")
+def factory_involving_factories_fixture(unused_tcp_port_factory):
+    def factory():
+        return unused_tcp_port_factory()
+
+    return factory
