@@ -10,8 +10,9 @@ from hypothesis import given, strategies as st
 
 @pytest.fixture(scope="module")
 def event_loop():
-    loop = asyncio.get_event_loop()
+    loop = asyncio.get_event_loop_policy().new_event_loop()
     yield loop
+    loop.close()
 
 
 @given(st.integers())
