@@ -1,12 +1,11 @@
 """Tests for using subprocesses in tests."""
-import sys
 import asyncio
 import asyncio.subprocess
+import sys
 
 import pytest
 
-
-if sys.platform == 'win32':
+if sys.platform == "win32":
     # The default asyncio event loop implementation on Windows does not
     # support subprocesses. Subprocesses are available for Windows if a
     # ProactorEventLoop is used.
@@ -21,7 +20,8 @@ if sys.platform == 'win32':
 async def test_subprocess(event_loop):
     """Starting a subprocess should be possible."""
     proc = await asyncio.subprocess.create_subprocess_exec(
-        sys.executable, '--version', stdout=asyncio.subprocess.PIPE)
+        sys.executable, "--version", stdout=asyncio.subprocess.PIPE
+    )
     await proc.communicate()
 
 
@@ -29,5 +29,6 @@ async def test_subprocess(event_loop):
 async def test_subprocess_forbid(event_loop):
     """Starting a subprocess should be possible."""
     proc = await asyncio.subprocess.create_subprocess_exec(
-        sys.executable, '--version', stdout=asyncio.subprocess.PIPE)
+        sys.executable, "--version", stdout=asyncio.subprocess.PIPE
+    )
     await proc.communicate()
